@@ -403,7 +403,9 @@ visualize_case_control_matrix <- function(mat, dim_names = ncol(mat),
   cex_main = min(2,20 / n)
   cex_se  = min(1.5,15 / n)
   
-  graphics::par(mar = c(0, 0, 5, 0), bg = "white",xpd = TRUE)
+  op <- graphics::par(mar = c(0, 0, 5, 0), bg = "white",xpd = TRUE)
+  on.exit(par(op))
+  
   graphics::plot(
     c(0, n + 0.8), c(0, n + 0.8), axes = axes, xlab = "",
     ylab = "", asp = 1, type = "n"
@@ -930,11 +932,11 @@ set_strat <- function(X,X_reg) {
 #'
 #' @details Note that this function should be used with caution. It used
 #' \deqn{nrow(X)/nrow(unique(X[,X_reg,drop=FALSE]))>10} as an *ad hoc* criterion.
-#' It is not the same as [plyr::is.discrete()]
+#' It is not the same as `is.discrete()` in `plyr`
 #'
 #' @param X   A data frame of covariates
 #' @param X_reg The vector of covariates that will stratify the analyses. These
-#' variables have to be categorical. Or a formula (can be tested by `plyr::is.formula`), 
+#' variables have to be categorical. Or a formula (can be tested by `is.formula` in `plyr`), 
 #' e.g., `~as.factor(SITE8) + as.factor(AGECAT > 1)`.
 #'
 #' @return `TRUE` for all being discrete; `FALSE` otherwise.
@@ -1501,6 +1503,7 @@ as.matrix_or_vec <- function(x){
   as.matrix(x)
 }
 
+
 #' get index of latent status
 #' 
 #' @param cause_list see mode_options in [nplcm()]
@@ -1695,7 +1698,7 @@ has_non_basis <- function(form){
   outlab <- attr(out,"term.labels")
   (attr(out,"intercept")>0) ||
     (length(grep("^s_",outlab))>=1 && length(outlab[-grep("^s_",outlab)])>=1 && attr(out,"intercept")==0) ||
-     (length(outlab)>=1 && length(grep("^s_",outlab))==0 && attr(out,"intercept")==0) 
+    (length(outlab)>=1 && length(grep("^s_",outlab))==0 && attr(out,"intercept")==0) 
 }
 
 #' Make Etiology design matrix for dates with R format.
@@ -1921,6 +1924,22 @@ jags2_baker <- function (data, inits, parameters.to.save, model.file = "model.bu
     }
   }
   lapply(names(data.list), dump, append = TRUE, file = "jagsdata.txt")
+  
+  
+  ## ZW fix:
+  ## fix a problem related to dumped matrix having a structure attribute of dim not
+  ## .Dim as desired by JAGS 4.3.2; also the dimension could be represented by 7:6
+  ## instead of c(7,6), which may cause problems - so fixing this here.
+  bad_jagsdata_txt <- readLines("jagsdata.txt")
+  good_jagsdata_txt <- gsub( ", dim =", ", .Dim=", 
+                             gsub( "([0-9]+):([0-9]+)", "c(\\1,\\2)", bad_jagsdata_txt,fixed = FALSE),
+                             fixed = FALSE)
+  writeLines(good_jagsdata_txt, "jagsdata.txt")
+  
+  #### end of data fix.
+  
+  
+  
   data <- read.jagsdata("jagsdata.txt")
   if (is.function(model.file)) {
     temp <- tempfile("model")
@@ -1959,15 +1978,14 @@ jags2_baker <- function (data, inits, parameters.to.save, model.file = "model.bu
       with(initial.values, dump(names(initial.values), 
                                 file = curr_init_txt_file))
       
-      # fix dimension problem.... convert say 7:6 to c(7,6) (an issue for a dumped matrix):
-      inits_fnames <- list.files(pattern = "^jagsinits[0-9]+.txt",
-                                 full.names = TRUE)
-      for (fiter in seq_along(inits_fnames)){
-        curr_inits_txt_file <- inits_fnames[fiter]
-        bad_jagsinits_txt <- readLines(curr_inits_txt_file)
-        good_jagsinits_txt <- gsub( "([0-9]+):([0-9]+)", "c(\\1L,\\2L)", bad_jagsinits_txt,fixed = FALSE)
-        writeLines(good_jagsinits_txt, curr_inits_txt_file)
-      }
+      ## ZW fix:
+      bad_jagsinits_txt <- readLines(curr_init_txt_file)
+      good_jagsinits_txt <- gsub( ", dim =", ", .Dim=",
+                                  gsub( "([0-9]+):([0-9]+)", "c(\\1,\\2)",
+                                        bad_jagsinits_txt,fixed = FALSE),
+                                  fixed = FALSE)
+      writeLines(good_jagsinits_txt, curr_init_txt_file)
+      ## end of inits fix.
       
       
     }
